@@ -13,6 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.cloud.contact_center_insights import gapic_version as package_version
+
+__version__ = package_version.__version__
+
 
 from google.cloud.contact_center_insights_v1.services.contact_center_insights.async_client import (
     ContactCenterInsightsAsyncClient,
@@ -21,6 +25,9 @@ from google.cloud.contact_center_insights_v1.services.contact_center_insights.cl
     ContactCenterInsightsClient,
 )
 from google.cloud.contact_center_insights_v1.types.contact_center_insights import (
+    BulkAnalyzeConversationsMetadata,
+    BulkAnalyzeConversationsRequest,
+    BulkAnalyzeConversationsResponse,
     CalculateIssueModelStatsRequest,
     CalculateIssueModelStatsResponse,
     CalculateStatsRequest,
@@ -37,6 +44,7 @@ from google.cloud.contact_center_insights_v1.types.contact_center_insights impor
     DeleteConversationRequest,
     DeleteIssueModelMetadata,
     DeleteIssueModelRequest,
+    DeleteIssueRequest,
     DeletePhraseMatcherRequest,
     DeleteViewRequest,
     DeployIssueModelMetadata,
@@ -52,6 +60,9 @@ from google.cloud.contact_center_insights_v1.types.contact_center_insights impor
     GetPhraseMatcherRequest,
     GetSettingsRequest,
     GetViewRequest,
+    IngestConversationsMetadata,
+    IngestConversationsRequest,
+    IngestConversationsResponse,
     ListAnalysesRequest,
     ListAnalysesResponse,
     ListConversationsRequest,
@@ -78,6 +89,7 @@ from google.cloud.contact_center_insights_v1.types.resources import (
     Analysis,
     AnalysisResult,
     AnnotationBoundary,
+    AnnotatorSelector,
     AnswerFeedback,
     ArticleSuggestionData,
     CallAnnotation,
@@ -99,6 +111,7 @@ from google.cloud.contact_center_insights_v1.types.resources import (
     InterruptionData,
     Issue,
     IssueAssignment,
+    IssueMatchData,
     IssueModel,
     IssueModelLabelStats,
     IssueModelResult,
@@ -119,6 +132,9 @@ from google.cloud.contact_center_insights_v1.types.resources import (
 __all__ = (
     "ContactCenterInsightsClient",
     "ContactCenterInsightsAsyncClient",
+    "BulkAnalyzeConversationsMetadata",
+    "BulkAnalyzeConversationsRequest",
+    "BulkAnalyzeConversationsResponse",
     "CalculateIssueModelStatsRequest",
     "CalculateIssueModelStatsResponse",
     "CalculateStatsRequest",
@@ -134,6 +150,7 @@ __all__ = (
     "DeleteConversationRequest",
     "DeleteIssueModelMetadata",
     "DeleteIssueModelRequest",
+    "DeleteIssueRequest",
     "DeletePhraseMatcherRequest",
     "DeleteViewRequest",
     "DeployIssueModelMetadata",
@@ -149,6 +166,9 @@ __all__ = (
     "GetPhraseMatcherRequest",
     "GetSettingsRequest",
     "GetViewRequest",
+    "IngestConversationsMetadata",
+    "IngestConversationsRequest",
+    "IngestConversationsResponse",
     "ListAnalysesRequest",
     "ListAnalysesResponse",
     "ListConversationsRequest",
@@ -174,6 +194,7 @@ __all__ = (
     "Analysis",
     "AnalysisResult",
     "AnnotationBoundary",
+    "AnnotatorSelector",
     "AnswerFeedback",
     "ArticleSuggestionData",
     "CallAnnotation",
@@ -195,6 +216,7 @@ __all__ = (
     "InterruptionData",
     "Issue",
     "IssueAssignment",
+    "IssueMatchData",
     "IssueModel",
     "IssueModelLabelStats",
     "IssueModelResult",
