@@ -54,7 +54,7 @@ class ContactCenterInsightsGrpcAsyncIOTransport(ContactCenterInsightsTransport):
     def create_channel(
         cls,
         host: str = "contactcenterinsights.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -97,15 +97,15 @@ class ContactCenterInsightsGrpcAsyncIOTransport(ContactCenterInsightsTransport):
         self,
         *,
         host: str = "contactcenterinsights.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
-        channel: aio.Channel = None,
-        api_mtls_endpoint: str = None,
-        client_cert_source: Callable[[], Tuple[bytes, bytes]] = None,
-        ssl_channel_credentials: grpc.ChannelCredentials = None,
-        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
-        quota_project_id=None,
+        channel: Optional[aio.Channel] = None,
+        api_mtls_endpoint: Optional[str] = None,
+        client_cert_source: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
+        ssl_channel_credentials: Optional[grpc.ChannelCredentials] = None,
+        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
+        quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
         api_audience: Optional[str] = None,
@@ -513,6 +513,65 @@ class ContactCenterInsightsGrpcAsyncIOTransport(ContactCenterInsightsTransport):
             )
         return self._stubs["delete_analysis"]
 
+    @property
+    def bulk_analyze_conversations(
+        self,
+    ) -> Callable[
+        [contact_center_insights.BulkAnalyzeConversationsRequest],
+        Awaitable[operations_pb2.Operation],
+    ]:
+        r"""Return a callable for the bulk analyze conversations method over gRPC.
+
+        Analyzes multiple conversations in a single request.
+
+        Returns:
+            Callable[[~.BulkAnalyzeConversationsRequest],
+                    Awaitable[~.Operation]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "bulk_analyze_conversations" not in self._stubs:
+            self._stubs["bulk_analyze_conversations"] = self.grpc_channel.unary_unary(
+                "/google.cloud.contactcenterinsights.v1.ContactCenterInsights/BulkAnalyzeConversations",
+                request_serializer=contact_center_insights.BulkAnalyzeConversationsRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["bulk_analyze_conversations"]
+
+    @property
+    def ingest_conversations(
+        self,
+    ) -> Callable[
+        [contact_center_insights.IngestConversationsRequest],
+        Awaitable[operations_pb2.Operation],
+    ]:
+        r"""Return a callable for the ingest conversations method over gRPC.
+
+        Imports conversations and processes them according to
+        the user's configuration.
+
+        Returns:
+            Callable[[~.IngestConversationsRequest],
+                    Awaitable[~.Operation]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "ingest_conversations" not in self._stubs:
+            self._stubs["ingest_conversations"] = self.grpc_channel.unary_unary(
+                "/google.cloud.contactcenterinsights.v1.ContactCenterInsights/IngestConversations",
+                request_serializer=contact_center_insights.IngestConversationsRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["ingest_conversations"]
+
     @property
     def export_insights_data(
         self,
@@ -834,6 +893,34 @@ class ContactCenterInsightsGrpcAsyncIOTransport(ContactCenterInsightsTransport):
             )
         return self._stubs["update_issue"]
 
+    @property
+    def delete_issue(
+        self,
+    ) -> Callable[
+        [contact_center_insights.DeleteIssueRequest], Awaitable[empty_pb2.Empty]
+    ]:
+        r"""Return a callable for the delete issue method over gRPC.
+
+        Deletes an issue.
+
+        Returns:
+            Callable[[~.DeleteIssueRequest],
+                    Awaitable[~.Empty]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "delete_issue" not in self._stubs:
+            self._stubs["delete_issue"] = self.grpc_channel.unary_unary(
+                "/google.cloud.contactcenterinsights.v1.ContactCenterInsights/DeleteIssue",
+                request_serializer=contact_center_insights.DeleteIssueRequest.serialize,
+                response_deserializer=empty_pb2.Empty.FromString,
+            )
+        return self._stubs["delete_issue"]
+
     @property
     def calculate_issue_model_stats(
         self,
